## switch

[rzeczownik]

1. łącznik (napięcia), wyłącznik (sieciowy), kontakt (elektryczny)

We could use some light. Flip the switch on.
(Przydałoby nam się trochę światła. Naciśnij przełącznik.)

It's so dark that I can't even see the switch.
(Jest tak ciemno, że nawet nie widzę kontaktu.)

Don't touch the switch with wet hands.
(Nie dotykaj kontaktu mokrymi rękami.)

2. zmiana (z czegoś na coś), przejście (np. z komunizmu na kapitalizm)

For those looking to make the switch, some research is in order.
(Wszyscy, którzy chcą dokonać zmiany, powinni najpierw przeprowadzić badania.)

That switch will be good for our country.
(Ta zmiana będzie dobra dla naszego kraju.)

3. zwrotnica (kolejowa)

Somebody has to pull the switch or we won't make it.
(Ktoś musi pociągnąć za zwrotnicę albo nie damy rady.)

The two trains crashed into each other at the switch.
(Dwa pociągi zderzyły się ze sobą na zwrotnicy.)

4. rózga, witka

My grandfather hit me with the switch because I was naughty.
(Mój dziadek uderzył mnie rózgą, bo byłem niegrzeczny.)

His parents used to hit him with a switch as a punishment.
(Jego rodzice bili go rózgą w ramach kary.)

5. rozjazd kolejowy

The train stopped at a switch.
(Pociąg zatrzymał się na rozjeździe kolejowym.)

[czasownik]

1. przełączać (programy, stacje radiowe)

He switched channels, hoping to find something more interesting.
(Przełączył kanał, próbując znaleźć coś bardziej interesującego.)

Stop switching radio stations, it's annoying!
(Przestań przełączać stacje radiowe, to denerwujące!)

2. zmieniać (np. taktykę), przechodzić (z jednej strony na drugą), przerzucać (się na coś)

He had to switch sides, as the building he looked for was on the other side of the street.
(On musiał zmienić stronę, ponieważ budynek, którego szukał był po drugiej stronie ulicy.)

He switched to veganism when he started dating this girl.
(Przerzucił się na weganizm, kiedy zaczął spotykać się z tą dziewczyną.)

3. zastępować (coś czymś), wymieniać (coś na coś), zmieniać (rzecz na inną)

He switched his BMW for a Jeep.
(On zamienił swoje BMW na Jeepa.)

You should switch your old phone for a new one.
(Powinieneś wymienić swój stary telefon na jakiś nowy.)

## swap

## switch

[czasownik]

1. zamieniać (się), wymieniać (się)

I want to switch places with you.
(Chcę się z tobą zamienić miejscami.)